# Luxsci::EmailSendingApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_account_suppression**](EmailSendingApi.md#create_account_suppression) | **PUT** /account/{accountId}/suppression/ | 
[**create_custom_field**](EmailSendingApi.md#create_custom_field) | **PUT** /user/{username}/fields | 
[**create_email_content_tag**](EmailSendingApi.md#create_email_content_tag) | **PUT** /user/{username}/content_tags | 
[**create_email_template**](EmailSendingApi.md#create_email_template) | **PUT** /user/{username}/templates | 
[**create_email_template_group**](EmailSendingApi.md#create_email_template_group) | **PUT** /user/{username}/template_group/{template_group_id} | 
[**create_user_suppression**](EmailSendingApi.md#create_user_suppression) | **PUT** /user/{username}/suppression/ | 
[**delete_account_suppression**](EmailSendingApi.md#delete_account_suppression) | **DELETE** /account/{accountId}/suppression/{email} | 
[**delete_email_content_tag**](EmailSendingApi.md#delete_email_content_tag) | **DELETE** /user/{username}/content_tags/{tag_id} | 
[**delete_email_template**](EmailSendingApi.md#delete_email_template) | **DELETE** /user/{username}/template/{template_id} | 
[**delete_email_template_group**](EmailSendingApi.md#delete_email_template_group) | **DELETE** /user/{username}/template_group/{template_group_id} | 
[**delete_user_suppression**](EmailSendingApi.md#delete_user_suppression) | **DELETE** /user/{username}/suppression/{email} | 
[**get_account_suppression**](EmailSendingApi.md#get_account_suppression) | **GET** /account/{accountId}/suppression/{email} | 
[**get_account_suppression_list**](EmailSendingApi.md#get_account_suppression_list) | **GET** /account/{accountId}/suppression/ | 
[**get_custom_fields**](EmailSendingApi.md#get_custom_fields) | **GET** /user/{username}/fields | 
[**get_domain_smtp_tls_capability**](EmailSendingApi.md#get_domain_smtp_tls_capability) | **GET** /user/{username}/email/compose/secureline/tls/{domain} | 
[**get_email_content_tag**](EmailSendingApi.md#get_email_content_tag) | **GET** /user/{username}/content_tags/{tag_id} | 
[**get_email_content_tag_list**](EmailSendingApi.md#get_email_content_tag_list) | **GET** /user/{username}/content_tags | 
[**get_email_template**](EmailSendingApi.md#get_email_template) | **GET** /user/{username}/template/{template_id} | 
[**get_email_template_groups**](EmailSendingApi.md#get_email_template_groups) | **GET** /user/{username}/template_groups | 
[**get_email_template_list**](EmailSendingApi.md#get_email_template_list) | **GET** /user/{username}/templates | 
[**get_user_suppression**](EmailSendingApi.md#get_user_suppression) | **GET** /user/{username}/suppression/{email} | 
[**get_user_suppression_list**](EmailSendingApi.md#get_user_suppression_list) | **GET** /user/{username}/suppression/ | 
[**send_email**](EmailSendingApi.md#send_email) | **POST** /user/{username}/email/send | 
[**send_email**](EmailSendingApi.md#send_email) | **POST** /user/{username}/email/send | 
[**send_secure_email_or_secure_text**](EmailSendingApi.md#send_secure_email_or_secure_text) | **POST** /user/{username}/email/compose/secureline/send | 
[**update_email_content_tag**](EmailSendingApi.md#update_email_content_tag) | **POST** /user/{username}/content_tags/{tag_id} | 
[**update_email_template**](EmailSendingApi.md#update_email_template) | **POST** /user/{username}/template/{template_id} | 
[**update_email_template_group**](EmailSendingApi.md#update_email_template_group) | **POST** /user/{username}/template_group/{template_group_id} | 

# **create_account_suppression**
> InlineResponse2003 create_account_suppression(account_id, opts)



Add new email suppressions at the account level. {{ACL: User Email: Suppression}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
account_id = 56 # Integer | 
opts = { 
  body: Luxsci::Suppression.new # Suppression | 
}

begin
  result = api_instance.create_account_suppression(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_account_suppression: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **Integer**|  | 
 **body** | [**Suppression**](Suppression.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_custom_field**
> InlineResponse201 create_custom_field(username, opts)



Create a Custom Field.  These Custom Fields are useful for Secure Marketing v3 and for Advanced Secure High Volume.  Note that for users in Teams, only Team Administrators are permitted to make new Custom Fields. {{ACL: User Email: Custom Fields}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::UsernameFieldsBody.new # UsernameFieldsBody | 
}

begin
  result = api_instance.create_custom_field(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_custom_field: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**UsernameFieldsBody**](UsernameFieldsBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_email_content_tag**
> InlineResponse20017 create_email_content_tag(username, opts)



Define a new static email content tag.  {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::ContentTag.new # ContentTag | 
}

begin
  result = api_instance.create_email_content_tag(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_email_content_tag: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**ContentTag**](ContentTag.md)|  | [optional] 

### Return type

[**InlineResponse20017**](InlineResponse20017.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_email_template**
> InlineResponse20015 create_email_template(username, opts)



Create a new email template.  Note, templates created via the API will be required to use the WYSIWYG template editor if edited in the user interface.  {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::Template.new # Template | 
}

begin
  result = api_instance.create_email_template(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_email_template: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**Template**](Template.md)|  | [optional] 

### Return type

[**InlineResponse20015**](InlineResponse20015.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_email_template_group**
> InlineResponse20019 create_email_template_group(username, opts)



Create a new email template group. {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::TemplateGroupTemplateGroupIdBody.new # TemplateGroupTemplateGroupIdBody | 
}

begin
  result = api_instance.create_email_template_group(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_email_template_group: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**TemplateGroupTemplateGroupIdBody**](TemplateGroupTemplateGroupIdBody.md)|  | [optional] 

### Return type

[**InlineResponse20019**](InlineResponse20019.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **create_user_suppression**
> InlineResponse2003 create_user_suppression(username, opts)



Add new email suppressions at the user level. {{ACL: User Email: Suppression}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::Suppression.new # Suppression | 
}

begin
  result = api_instance.create_user_suppression(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->create_user_suppression: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**Suppression**](Suppression.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **delete_account_suppression**
> InlineResponse2003 delete_account_suppression(account_id, email, opts)



Delete a specific account-level email suppression. {{ACL: User Email: Suppression}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
account_id = 'account_id_example' # String | 
email = 'email_example' # String | Suppression email address to be deleted.
opts = { 
}

begin
  result = api_instance.delete_account_suppression(account_id, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_account_suppression: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 
 **email** | **String**| Suppression email address to be deleted. | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **delete_email_content_tag**
> InlineResponse2003 delete_email_content_tag(username, tag_id, opts)



Delete a specific email content tag.  {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
tag_id = 'tag_id_example' # String | tag_id can be either the unique numerical tag_id or the text code_word
opts = { 
}

begin
  result = api_instance.delete_email_content_tag(username, tag_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_email_content_tag: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **tag_id** | **String**| tag_id can be either the unique numerical tag_id or the text code_word | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **delete_email_template**
> InlineResponse2003 delete_email_template(username, template_id, opts)



Delete a specific email template.  {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_id = 'template_id_example' # String | template_id can be either the unique numerical template_id or the text code_word
opts = { 
}

begin
  result = api_instance.delete_email_template(username, template_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_email_template: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **template_id** | **String**| template_id can be either the unique numerical template_id or the text code_word | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **delete_email_template_group**
> InlineResponse2003 delete_email_template_group(username, template_group_id, opts)



Delete a specific email template group.  {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_group_id = 'template_group_id_example' # String | Unique Id for this template group.
opts = { 
}

begin
  result = api_instance.delete_email_template_group(username, template_group_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_email_template_group: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **template_group_id** | **String**| Unique Id for this template group. | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **delete_user_suppression**
> InlineResponse2003 delete_user_suppression(username, email, opts)



Delete a specific user-level email suppression. {{ACL: User Email: Suppression}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
email = 'email_example' # String | Suppression email address to be deleted.
opts = { 
}

begin
  result = api_instance.delete_user_suppression(username, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->delete_user_suppression: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **email** | **String**| Suppression email address to be deleted. | 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_account_suppression**
> InlineResponse20012 get_account_suppression(account_id, email, opts)



Retrieve a specific email suppression at the account level. {{ACL: User Email: Suppression}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
account_id = 56 # Integer | 
email = 'email_example' # String | Suppression email address to be retrieved. You are returning all suppression entries that contain the string 'email'.  Note that even if you specify a full email address for 'email,' you can get multiple matches.
opts = { 
}

begin
  result = api_instance.get_account_suppression(account_id, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_account_suppression: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **Integer**|  | 
 **email** | **String**| Suppression email address to be retrieved. You are returning all suppression entries that contain the string &#x27;email&#x27;.  Note that even if you specify a full email address for &#x27;email,&#x27; you can get multiple matches. | 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_account_suppression_list**
> InlineResponse20012 get_account_suppression_list(account_id, opts)



Retrieve all email suppressions at the account level. See also the newer and more general function: getAccountSuppressionReport.  {{ACL: User Email: Suppression}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
account_id = 'account_id_example' # String | 
opts = { 
}

begin
  result = api_instance.get_account_suppression_list(account_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_account_suppression_list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_id** | **String**|  | 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_custom_fields**
> InlineResponse20044 get_custom_fields(username, opts)



Retrieve a list of all Custom Fields visible to user {username}.  These Custom Fields are useful for Secure Marketing v3 and for Advanced Secure High Volume. {{ACL: User Email: Custom Fields}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_custom_fields(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_custom_fields: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse20044**](InlineResponse20044.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_domain_smtp_tls_capability**
> InlineResponse20010 get_domain_smtp_tls_capability(username, domain, opts)



This function checks if a specific domain name supports “good” SMTP TLS for email delivery to its users. This means: - All MX records are working - SMTP TLS is supported by all MX records - TLS support includes TLS v1.0+ and strong (NIST 800-52 recommended) ciphers like AES256.  For more background, see: - [About SMTP TLS](https://luxsci.com/blog/smtp-tls-all-about-secure-email-delivery-over-tls.html) - [What Level of SSL/TLS is needed for HIPAA?](https://luxsci.com/blog/level-ssl-tls-required-hipaa.html) {{ACL: User Email - Sending}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
domain = 'domain_example' # String | 
opts = { 
}

begin
  result = api_instance.get_domain_smtp_tls_capability(username, domain, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_domain_smtp_tls_capability: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **domain** | **String**|  | 

### Return type

[**InlineResponse20010**](InlineResponse20010.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_email_content_tag**
> InlineResponse20018 get_email_content_tag(username, tag_id, opts)



The call returns the specific details around a specific Email Content Tag {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
tag_id = 'tag_id_example' # String | can either be the numerical unique ID of the Cotent Tag, or its 'code_word'
opts = { 
}

begin
  result = api_instance.get_email_content_tag(username, tag_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_content_tag: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **tag_id** | **String**| can either be the numerical unique ID of the Cotent Tag, or its &#x27;code_word&#x27; | 

### Return type

[**InlineResponse20018**](InlineResponse20018.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_email_content_tag_list**
> InlineResponse20016 get_email_content_tag_list(username, opts)



This function returns a list of all content tags accessible to you.  {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_email_content_tag_list(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_content_tag_list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse20016**](InlineResponse20016.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_email_template**
> InlineResponse20013 get_email_template(username, template_id, opts)



The call returns the specific details around a specific Email Template. {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_id = 'template_id_example' # String | can either be the numerical unique ID of the template, or the textual “code_word”
opts = { 
}

begin
  result = api_instance.get_email_template(username, template_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_template: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **template_id** | **String**| can either be the numerical unique ID of the template, or the textual “code_word” | 

### Return type

[**InlineResponse20013**](InlineResponse20013.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_email_template_groups**
> InlineResponse20020 get_email_template_groups(username, opts)



This function returns a list of all templates groups accessible to you.  {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_email_template_groups(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_template_groups: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse20020**](InlineResponse20020.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_email_template_list**
> InlineResponse20014 get_email_template_list(username, opts)



This function returns a list of all templates accessible to you.  {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  user_id: 56, # Integer | Restricts the templates returned to only those owned by a specific user, [user_id].  This is relevent when [username] used belongs to a Team. In that case, all non-private Templates of all Team members are returned by this call unless this parameter is specified.
}

begin
  result = api_instance.get_email_template_list(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_email_template_list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **user_id** | **Integer**| Restricts the templates returned to only those owned by a specific user, [user_id].  This is relevent when [username] used belongs to a Team. In that case, all non-private Templates of all Team members are returned by this call unless this parameter is specified. | [optional] 

### Return type

[**InlineResponse20014**](InlineResponse20014.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_suppression**
> InlineResponse20012 get_user_suppression(username, email, opts)



Retrieve a specific email suppression at the user level. {{ACL: User Email: Suppression}}.  See also the newer and more general function: getUserSuppressionReport.

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
email = 'email_example' # String | Suppression email address to be retrieved. You are returning all suppression entries that contain the string 'email'.  Note that even if you specify a full email address for 'email,' you can get multiple matches.
opts = { 
}

begin
  result = api_instance.get_user_suppression(username, email, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_user_suppression: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **email** | **String**| Suppression email address to be retrieved. You are returning all suppression entries that contain the string &#x27;email&#x27;.  Note that even if you specify a full email address for &#x27;email,&#x27; you can get multiple matches. | 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **get_user_suppression_list**
> InlineResponse20012 get_user_suppression_list(username, opts)



Retrieve all email suppressions at the user level in a simple list. {{ACL: User Email: Suppression}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
}

begin
  result = api_instance.get_user_suppression_list(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->get_user_suppression_list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **send_email**
> InlineResponse20012 send_email(username, opts)



This API call is a generic outbound email sending interface that is designed to enable efficient large-scale email sending through your account’s email servers.  It is ideal for Secure High Volume email sending.  See - [sendEmail vs sendSecureEmailOrSecureText endpoints](/rest-api/sending-email.html) for sending email via the LuxSci API.  This API function is used to send message(s) through your account’s SMTP server(s). You can think of it as an API-based proxy to SMTP, used for cases where direct use of SMTP is not an option. Generally speaking, direct use of SMTP is overall faster and more efficient; however, the API does include some things that you cannot get through direct SMTP connections. For example, the API includes support for failover, load-balanced SMTP servers; this can be done with direct SMTP only if you have a load balancer in front of your servers. You can also hand off messages to LuxSci (into the outbound queues) faster through the API than you can through direct SMTP.  As this is a proxy for SMTP, the majority of the email message processing actually happens on the SMTP servers themselves (just like it would if you had actually used direct SMTP to send the message). The API call accepts the message, vets your ability to send the message, queues the message, and the moves it to the appropriate SMTP servers for delivery. This API process is designed to be very safe and efficient and works well for customers with very large SMTP sending limits (e.g., millions of messages per month).  This API function allows you to optionally include attachments. If you wish to include attachments, you must format your request as a `multipart/form-data` request as discussed in the [API Mechanics Guide](/rest-api/mechanics.html).  If the API call 'fails' it may be because more information is needed to encrypt the message to your recipients, if the request is malformed, or if your sending has exceeded some limit. Here are some limits to be aware of  1. The sending user must have an SMTP license. 2. The sending user must have a SecureLine license to use SecureLine-specific parameters. 3. You have to send to at least 1 recipient, but no more than 100 recipients per message. This limit can be increased on dedicated servers. 4. Your API call can contain 1 to 1000 messages. This limit can be increased on dedicated servers. 5. The total number of recipients across all messages in your API call cannot exceed 1000. This limit can be increased on dedicated servers. 6. The messages sent by a user through this API call count towards the users’ daily and monthly SMTP sending (just as if the user had actually used direct SMTP to send) totals. So, messages will be rejected if a user exceeds any of these limits. Please contact support if you need to upgrade these limits. 7. While SecureLine-encrypted emails sending is supported through this API call, SecureText sending is not. 8. If there are restrictions configured in the Domain Administration control panel on to whom the sending user can send messages, these restrictions also apply to messages sent through the API. 9. The total size of the message subject, body, and all attachments (raw size) must be less than or equal to 66% the sender’s SMTP message sending size limit. This limit can be affected by use of Email Archival, custom domain-level size limits, and general global limits. The current value of this limit can be found in the “Maximum Message Size Limit” for the sender’s domain in your domain administration settings area. 66% is used because, when the attachments are encoded into an actual email message, the size can bloat to 140-150% of the raw size; the SMTP message size limit looks at the size of the encoded messages passing through your SMTP servers.  Note that once messages sent via this API arrive on your SMTP server for processing and delivery, those messages are subject to any server delivery rate limiting settings currently enabled on the SMTP server. For example, if your SMTP server is “warming up” its IP address by slowly increasing its outbound email delivery rate, messages sent by the API through that server may be delayed by that warmup rate limit.  **Maximizing your sending rate:**  To deposit email messages in the outbound queues as fast as possible using the API, we recommend  1. Send as many messages as you can in each API call. This “pipelining” greatly reduces the number of API calls you need to execute and greatly speeds up processing of your messages. 2. When sending same attachments in multiple messages, use the API’s feature for including the attachment once and referencing it in each of the actual messages. This will greatly speed up the uploading/posting of your message information to the API server. 3. Keep the messages as small as possible. 4. If appropriate for your use case, send fewer messages. Have more recipients per message (using the `bcc` field if needed). 5. Ask support about dedicated API servers. If all of the server resources are dedicated to your account, your throughput can be higher. You can also use multiple load-balanced dedicated API sending servers to scale your throughput capacity. 6. Use the `priority` field to ensure that more important messages are processed and delivered before less important messages.  Under ideal conditions, you should be able to deposit outbound email messages in the API queues much faster that your email servers can actually deliver those messages to the actual recipients (unless you have a number of powerful dedicated email servers). That is OK, your email servers will just process and delivery them as fast as they can. The actual rate of message delivery to the recipients will be a function of how many email servers you have, what their specs are, how busy they are, and many other factors involved in SMTP email delivery – such as the recipients’ DNS response time, the recipient’s inbound email server speeds, etc. {{ACL: User Email: Sending}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::EmailSendBody.new # EmailSendBody | 
}

begin
  result = api_instance.send_email(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->send_email: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**EmailSendBody**](EmailSendBody.md)|  | [optional] 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json



# **send_email**
> InlineResponse20012 send_email(username, opts)



This API call is a generic outbound email sending interface that is designed to enable efficient large-scale email sending through your account’s email servers.  It is ideal for Secure High Volume email sending.  See - [sendEmail vs sendSecureEmailOrSecureText endpoints](/rest-api/sending-email.html) for sending email via the LuxSci API.  This API function is used to send message(s) through your account’s SMTP server(s). You can think of it as an API-based proxy to SMTP, used for cases where direct use of SMTP is not an option. Generally speaking, direct use of SMTP is overall faster and more efficient; however, the API does include some things that you cannot get through direct SMTP connections. For example, the API includes support for failover, load-balanced SMTP servers; this can be done with direct SMTP only if you have a load balancer in front of your servers. You can also hand off messages to LuxSci (into the outbound queues) faster through the API than you can through direct SMTP.  As this is a proxy for SMTP, the majority of the email message processing actually happens on the SMTP servers themselves (just like it would if you had actually used direct SMTP to send the message). The API call accepts the message, vets your ability to send the message, queues the message, and the moves it to the appropriate SMTP servers for delivery. This API process is designed to be very safe and efficient and works well for customers with very large SMTP sending limits (e.g., millions of messages per month).  This API function allows you to optionally include attachments. If you wish to include attachments, you must format your request as a `multipart/form-data` request as discussed in the [API Mechanics Guide](/rest-api/mechanics.html).  If the API call 'fails' it may be because more information is needed to encrypt the message to your recipients, if the request is malformed, or if your sending has exceeded some limit. Here are some limits to be aware of  1. The sending user must have an SMTP license. 2. The sending user must have a SecureLine license to use SecureLine-specific parameters. 3. You have to send to at least 1 recipient, but no more than 100 recipients per message. This limit can be increased on dedicated servers. 4. Your API call can contain 1 to 1000 messages. This limit can be increased on dedicated servers. 5. The total number of recipients across all messages in your API call cannot exceed 1000. This limit can be increased on dedicated servers. 6. The messages sent by a user through this API call count towards the users’ daily and monthly SMTP sending (just as if the user had actually used direct SMTP to send) totals. So, messages will be rejected if a user exceeds any of these limits. Please contact support if you need to upgrade these limits. 7. While SecureLine-encrypted emails sending is supported through this API call, SecureText sending is not. 8. If there are restrictions configured in the Domain Administration control panel on to whom the sending user can send messages, these restrictions also apply to messages sent through the API. 9. The total size of the message subject, body, and all attachments (raw size) must be less than or equal to 66% the sender’s SMTP message sending size limit. This limit can be affected by use of Email Archival, custom domain-level size limits, and general global limits. The current value of this limit can be found in the “Maximum Message Size Limit” for the sender’s domain in your domain administration settings area. 66% is used because, when the attachments are encoded into an actual email message, the size can bloat to 140-150% of the raw size; the SMTP message size limit looks at the size of the encoded messages passing through your SMTP servers.  Note that once messages sent via this API arrive on your SMTP server for processing and delivery, those messages are subject to any server delivery rate limiting settings currently enabled on the SMTP server. For example, if your SMTP server is “warming up” its IP address by slowly increasing its outbound email delivery rate, messages sent by the API through that server may be delayed by that warmup rate limit.  **Maximizing your sending rate:**  To deposit email messages in the outbound queues as fast as possible using the API, we recommend  1. Send as many messages as you can in each API call. This “pipelining” greatly reduces the number of API calls you need to execute and greatly speeds up processing of your messages. 2. When sending same attachments in multiple messages, use the API’s feature for including the attachment once and referencing it in each of the actual messages. This will greatly speed up the uploading/posting of your message information to the API server. 3. Keep the messages as small as possible. 4. If appropriate for your use case, send fewer messages. Have more recipients per message (using the `bcc` field if needed). 5. Ask support about dedicated API servers. If all of the server resources are dedicated to your account, your throughput can be higher. You can also use multiple load-balanced dedicated API sending servers to scale your throughput capacity. 6. Use the `priority` field to ensure that more important messages are processed and delivered before less important messages.  Under ideal conditions, you should be able to deposit outbound email messages in the API queues much faster that your email servers can actually deliver those messages to the actual recipients (unless you have a number of powerful dedicated email servers). That is OK, your email servers will just process and delivery them as fast as they can. The actual rate of message delivery to the recipients will be a function of how many email servers you have, what their specs are, how busy they are, and many other factors involved in SMTP email delivery – such as the recipients’ DNS response time, the recipient’s inbound email server speeds, etc. {{ACL: User Email: Sending}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  json: Luxsci::UserusernameemailsendJson.new # UserusernameemailsendJson | 
  files: ['files_example'] # Array<String> | 
}

begin
  result = api_instance.send_email(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->send_email: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **json** | [**UserusernameemailsendJson**](.md)|  | [optional] 
 **files** | [**Array&lt;String&gt;**](String.md)|  | [optional] 

### Return type

[**InlineResponse20012**](InlineResponse20012.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json



# **send_secure_email_or_secure_text**
> InlineResponse201 send_secure_email_or_secure_text(username, opts)



Send Secure Email and/or SecureText messages through your WebMail servers.  This API endpoint is deprecated; use the sendEmail endpoint instead. See [sendEmail vs sendSecureEmailOrSecureText endpoints](/rest-api/sending-email.html) for sending email via the LuxSci API. {{ACL: User Email: Sending}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
opts = { 
  body: Luxsci::SecurelineSendBody.new # SecurelineSendBody | 
}

begin
  result = api_instance.send_secure_email_or_secure_text(username, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->send_secure_email_or_secure_text: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **body** | [**SecurelineSendBody**](SecurelineSendBody.md)|  | [optional] 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **update_email_content_tag**
> InlineResponse2003 update_email_content_tag(usernametag_id, opts)



This content tag update call will update/replace ALL FIELDS. So, include all fields, as omitted fields will be treated as if you are updating them with empty or false values.  This is effectively just like deleting the old tag with this `tag_id` and replacing it with the new data. Note, this call does not allow you to change the type of a Contet Tag or alter the inclusion rules for Dynamic Content Tags. {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
tag_id = 'tag_id_example' # String | tag_id can be either the unique numerical tag_id or the code_word.
opts = { 
  body: Luxsci::ContentTag.new # ContentTag | 
}

begin
  result = api_instance.update_email_content_tag(usernametag_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->update_email_content_tag: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **tag_id** | **String**| tag_id can be either the unique numerical tag_id or the code_word. | 
 **body** | [**ContentTag**](ContentTag.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **update_email_template**
> InlineResponse2003 update_email_template(usernametemplate_id, opts)



This template update call will update/replace ALL FIELDS. So, include all fields, as omitted fields will be treated as if you are updating them with empty or false values.  This is effectively just like deleting the old template with this `template_id` and replacing it with the new data.  Note, any template updated from the API will be required to use the WYSIWYG template editor when edited in the user interface. {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_id = 'template_id_example' # String | template_id can be either the unique numerical template_id or the text code_word.
opts = { 
  body: Luxsci::Template.new # Template | 
}

begin
  result = api_instance.update_email_template(usernametemplate_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->update_email_template: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **template_id** | **String**| template_id can be either the unique numerical template_id or the text code_word. | 
 **body** | [**Template**](Template.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **update_email_template_group**
> InlineResponse2003 update_email_template_group(usernametemplate_group_id, opts)



Update the Template Group name. {{ACL: User Email: Templates}}

### Example
```ruby
# load the gem
require 'luxsci'

api_instance = Luxsci::EmailSendingApi.new
username = 'username_example' # String | 
template_group_id = 'template_group_id_example' # String | Unique Id for this template group.
opts = { 
  body: Luxsci::TemplateGroupTemplateGroupIdBody1.new # TemplateGroupTemplateGroupIdBody1 | 
}

begin
  result = api_instance.update_email_template_group(usernametemplate_group_id, opts)
  p result
rescue Luxsci::ApiError => e
  puts "Exception when calling EmailSendingApi->update_email_template_group: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  | 
 **template_group_id** | **String**| Unique Id for this template group. | 
 **body** | [**TemplateGroupTemplateGroupIdBody1**](TemplateGroupTemplateGroupIdBody1.md)|  | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



